%this is a wrapper script to estimate the selection model and calculate
%selection corrected estimates based on Andrews and Kasy (2017)

clear;
rng(1);
%create a folder "FiguresandTables" under this path to save figures and tables

%Estimate baseline model, rather than running spec test against p(z, theta)
spec_test=0;
%To replicate results in the main text, refer to AllApplicationsm and set the variable application accordingly. Set it to zero unless you are replicating results in the main text (and in that case, you should be using AllApplications.m
application=0;


%% data preparation and parametric specification
%Based on your study type (replication studies or meta studies), edit and
%run corresponding section below for data preparation.
%identificationapproach = 1 if replication studies;
%identificationapproach = 2 if meta studies.

    identificationapproach=2
    
if identificationapproach==1
% replication studies

	%date is formatted as [original study X1, sigma1, replication
    %study X2, sigma2]
    data=csvread('../Applications/EconExperiments/cleaned_econ_data.csv');
    
    %Make sure Studynames is an nx1 cell array where n is the number of
    %studies
    Studynames = textscan(fopen('../Applications/EconExperiments/sorted_names.csv','r'), '%s%[^\n\r]', 'Delimiter', ';');
    Studynames=Studynames{1}

    %Name for outputs
    name='ReplicationEcon';
 
 	%Assign these variables based on your dataset and parametric specification but do not change the variable names

    X=data(:,1); %X1
    sigma=data(:,2); %sigma1
    Z=[data(:,1)./data(:,2) data(:,3)./data(:,2)]; %[X1/sigma1, X2/sigma1]
    sigmaZ2=data(:,4)./data(:,2); %sigma1/sigma2
    
    %Use a step function symmetric around zero, and set thetabar=0 for MLE
    symmetric=1;
    %Set cutoffs to use in step function: should be given in increasing order;
    cutoffs=1.96;
    %starting values for optimization: thetabar is fixed at zero due to sign normalization
    Psihat0=[2,1];    %[tau, betap(1)]
    
    n=size(Z,1); %number of studies
    cluster_ID=(1:n)';     % for cluster-robust variance estimation
    %for replication studies, there is no clustering i.e. each study is its own cluster
    
elseif identificationapproach==2
%  meta studies     
    %data is formatted as [original study X1, sigma1]   
    data=csvread('../Applications/deworming/cleaned_deworming_data.csv');
    %Make sure Studynames is an nx1 cell array where n is the number of
    %studies
    Studynames=table2array(readtable('../Applications/deworming/DewormingLabels.csv'));
    Studynames=Studynames(:,1)
    
    %Name for outputs
    name='DewormingAsymmetric';
    
	%Assign these variables based on your dataset and parametric specification but do not change the variable names
	X=data(:,1);
    sigma=data(:,2);
    % for cluster-robust variance estimation
    cluster_ID=data(:,3); %categorical variable specified to which study each estimate belongs
    includeinestimation=logical(ones(length(X),1)); %indicator variable 1=the estimate is used in estimating the selection model - see EstimatingSelection.m
    %this can also be a column e.g. publication status from your dataset for robustness checks
    

    %Allow an asymmetric specification of thetastar
    symmetric=0;
    %Allow an asymmetric specification of p(z)
    symmetric_p=0;
    %Set cutoffs to use in step function: should be given in increasing order;
    cutoffs=[-1.96 0 1.96];
    %starting values for optimization
    Psihat0=[0,1,1,1,1]; %[thetabar, tau, betap(i)];dimension of betap(i) corresponds to cutoff
    
    
    
    n=length(X);

    
    
end
%%
%producing figures: 
%binned density plot for Z1; 
%scatter plot of initial Z1 against replication Z2 (for replication studies only); 
%scatter plot of initial X1 against standard errors (for replication studies and meta studies)
    

    if identificationapproach==1
        DescriptiveStats(Z,sigmaZ2, 1,name,symmetric,cluster_ID);
        DescriptiveStats(X,sigma, 2,[name 'Sanitycheck'],symmetric,cluster_ID);
        DescriptiveStatsCombined(Z,X,sigma,name,symmetric);
    else
        DescriptiveStats(X,sigma, 2,name,symmetric,cluster_ID);
    end
 

%%
%estimating the model

 
    EstimatingSelection
 


%%
%producing bias-corrected estimates and confidence sets

 
    HorizontalBars
%%
%output selection bias corrected estimates and confidence sets to a csv file:
%Z1 is the original z-statistic, Z1_M is median unbiased estimator, Z1_L and Z1_U
%form a selection corrected confidence set for the estimate.
    AdjustedZtable = table(Studynames, Z1, Z1_L, Z1_M, Z1_U )
    writetable(AdjustedZtable, ['../FiguresandTables/' name 'AdjustedZtable.csv']);
 