GREY=[.7 .7 .7];
SLIDE_GREY=[.6 .6 .6];
BLUE=[.4 .4 .8];

%normalize estimates from initial study
if identificationapproach==1
    Z1=Z(:,1);%.*sign(X(:,1));
elseif identificationapproach==2
    Z1=sort(X./sigma);
end

alpha=0.05;

%Pad Psihat_use with additional zeros in symmetric specifications to make
%dimensions conform
if symmetric==1
    Psihat_use=[0 Psihat];
else
    if symmetric_p==1
        Psihat_use=[Psihat(1), Psihat(2), [1 Psihat(3:end) fliplr(Psihat(3:end))]];
    else
        Psihat_use=Psihat;
    end
end

%Calculate corrected estimates and confidence bounds

for n=1:length(Z1)
    g_U=@(lambda)(alpha/2-Step_function_normal_cdf(Z1(n),lambda,1,[Psihat_use(3:end) 1],cutoffs,symmetric)).^2;
    g_L=@(lambda)(1-alpha/2-Step_function_normal_cdf(Z1(n),lambda,1,[Psihat_use(3:end) 1],cutoffs,symmetric)).^2;
    g_M=@(lambda) (1/2-Step_function_normal_cdf(Z1(n),lambda,1,[Psihat_use(3:end) 1],cutoffs,symmetric)).^2;
    
    Z1_M(n,1)=fminsearch(g_M,Z1(n));
    Z1_U(n,1)=fminsearch(g_U,Z1(n));
    Z1_L(n,1)=fminsearch(g_L,Z1(n));
end


count=1;
for lambda=-10:.01:10
    store(count)=g_M(lambda);
    count=count+1;
end

%% Plot original and adjusted confidence sets
Rl=min(min(Z1_L), min(Z1)-2)-0.5;
Ru=max(max(Z1_U), max(Z1)+2)+0.5;
R=Ru-Rl;

H=3.5;
W=6;

% fig=figure('Visible','on',...
%     'PaperPosition',[0 0 R n/2],...
%     'PaperSize',[R n/2])

fig=figure('Visible','on',...
    'PaperPosition',[0 0 W H],...
    'PaperSize',[W H])

ax=axes
hold on
axis([Rl/R*W Ru/R*W 0 H])
set(ax, 'XAxisLocation', 'top')
ax.YTick=1/n:H/n:H;
ax.YTickLabel = Studynames;
ax.XTick=(ceil(Rl/2):1:floor(Ru/2))/R*W*2;
ax.XTickLabel = ceil(Rl/2)*2:2:floor(Ru/2)*2+10^-8;
ax.FontSize=9;
line([0 0],[0 n+1],'Color',GREY)
line([1.96/R*W 1.96/R*W],[0 n+1],'Color',GREY)
line([-1.96/R*W -1.96/R*W],[0 n+1],'Color',GREY)


sc1=scatter(Z1/R*W, (1:n)/n*H, 15, BLUE, 'x') %original
sc2=scatter(Z1_M/R*W, ((1:n)-.3)/n*H, 15,[0 0 0], 'filled') %adjusted
% scatter(Z2_rescaled, (1:n)-.2, 15, [0 0 .5], 'd') %replicate


for i=1:n
    line([Z1(i)-1.96 Z1(i)+1.96]/R*W,[i i]/n*H,'Color',BLUE,'Linewidth',1) %original
    line([Z1_L(i) Z1_U(i)]/R*W,([i i]-.3)/n*H,'Color',[0 0 0],'Linewidth',1) %adjusted
    %line([Z2_rescaled(i) - 1.96*SE_2over1 Z2_rescaled(i) + 1.96*SE_2over1],[i i]-.4,'Color',[0 0 .5]) %replicate
end


legend([sc1 sc2],{'Original Estimates','Adjusted Estimates'},'Location','SE', 'FontSize', 9)


print(fig,'-dpdf', ['../FiguresandTables/' name 'OriginalAndAdjusted.pdf'])

%% Plot original and adjusted confidence sets for slides
Rl=min(min(Z1_L), min(Z1)-2)-0.5;
Ru=max(max(Z1_U), max(Z1)+2)+0.5;
R=Ru-Rl;

fig=figure('Visible','on',...
    'PaperPosition',[0 0 R n/2],...
    'PaperSize',[R n/2])

ax=axes
hold on
axis([Rl Ru 0 n+1])
set(ax, 'XAxisLocation', 'top')
ax.YTick=1:n
ax.YTickLabel = Studynames;
line([0 0],[0 n+1],'Color',SLIDE_GREY,'linewidth',1.5)
line([1.96 1.96],[0 n+1],'Color',SLIDE_GREY,'linewidth',1.5)
line([-1.96 -1.96],[0 n+1],'Color',SLIDE_GREY,'linewidth',1.5)


sc1=scatter(Z1, (1:n), 15, BLUE, 'x') %original
sc2=scatter(Z1_M, (1:n)-.2, 15,[0 0 0], 'filled') %adjusted
% scatter(Z2_rescaled, (1:n)-.2, 15, [0 0 .5], 'd') %replicate


for i=1:n
    line([Z1(i)-1.96 Z1(i)+1.96],[i i],'Color',BLUE,'linewidth',1.5) %original
    line([Z1_L(i) Z1_U(i)],[i i]-.2,'Color',[0 0 0],'linewidth',1.5) %adjusted
    %line([Z2_rescaled(i) - 1.96*SE_2over1 Z2_rescaled(i) + 1.96*SE_2over1],[i i]-.4,'Color',[0 0 .5]) %replicate
end


legend([sc1 sc2],{'Original Estimates','Adjusted Estimates'},'Location','SE', 'FontSize', 16)


print(fig,'-dpdf', ['../FiguresandTables/' name 'OriginalAndAdjustedSlides.pdf'])


%% Plot original, adjusted, and replication point estimates
if identificationapproach==1
    Z2=Z(:,2);%.*sign(X(:,1));
    Z2_rescaled=Z2;%.*sigmaX2;
    
    H=3.5;
    W=6;
    
    fig=figure('Visible','on',...
        'PaperPosition',[0 0 W H],...
        'PaperSize',[W H])
    
    
    ax=axes
    hold on
    axis([Rl/R*W Ru/R*W 0 H])
    set(ax, 'XAxisLocation', 'top')
    ax.YTick=1/n:H/n:H;
    ax.YTickLabel = Studynames;
    ax.XTick=(ceil(Rl/2):1:floor(Ru/2))/R*W*2;
    ax.XTickLabel = ceil(Rl/2)*2:2:floor(Ru/2)*2+10^-8;
    ax.FontSize=9;
    
    plot(Z1/R*W, (1/n:H/n:H), 'Color',BLUE,'LineWidth',1.5)
    plot(Z1_M/R*W, 1/n:H/n:H,'Color',[0 0 0],'LineWidth',1.5)
    plot(Z2_rescaled/R*W, (1/n:H/n:H), 'Color',GREY,'LineWidth',1.5)
    
    
    legend({'Original Estimates','Adjusted Estimates', 'Replication Estimates'},'Location','SE', 'FontSize', 9)
    
    print(fig,'-dpdf', ['../FiguresandTables/' name 'OriginalReplicationAndAdjusted.pdf'])
    
end

%% Plot original, adjusted, and replication point estimates for slides
if identificationapproach==1
    Z2=Z(:,2);%.*sign(X(:,1));
    Z2_rescaled=Z2;%.*sigmaX2;
    
    if application==2
        fig=figure('Visible','on',...
            'PaperPosition',[0 0 R n/8],...
            'PaperSize',[R n/8])
    elseif application==3
        fig=figure('Visible','on',...
            'PaperPosition',[0 0 R n/4],...
            'PaperSize',[R n/4])
    else
        fig=figure('Visible','on',...
            'PaperPosition',[0 0 R n/2],...
            'PaperSize',[R n/2])
    end
    
    ax=axes
    hold on
    axis([Rl Ru 0 n+1])
    set(ax, 'XAxisLocation', 'top')
    ax.YTick=1:n
    ax.YTickLabel = Studynames;
    
    plot(Z1, (1:n), 'Color',BLUE,'LineWidth',2)
    plot(Z1_M, 1:n,'Color',[0 0 0],'LineWidth',2)
    plot(Z2_rescaled, (1:n), 'Color',SLIDE_GREY,'LineWidth',2)
    
    
    legend({'Original Estimates','Adjusted Estimates', 'Replication Estimates'},'Location','SE', 'FontSize', 16)
    
    print(fig,'-dpdf', ['../FiguresandTables/' name 'OriginalReplicationAndAdjustedSlides.pdf'])
    
end


%%
%plot corrected estimators and confidence sets
if symmetric==1 | symmetric_p==1
    xgrid=0:.01:5;
    alpha=0.05;
    
    Theta_U_store=zeros(length(xgrid),1);
    Theta_L_store=zeros(length(xgrid),1);
    Theta_M_store=zeros(length(xgrid),1);
    for n=1:length(xgrid)
        X=xgrid(n);
        
        g_U=@(lambda)(alpha/2-Step_function_normal_cdf(X,lambda,1,[Psihat_use(3:end) 1],cutoffs,symmetric)).^2;
        g_L=@(lambda)(1-alpha/2-Step_function_normal_cdf(X,lambda,1,[Psihat_use(3:end) 1],cutoffs,symmetric)).^2;
        g_M=@(lambda) (1/2-Step_function_normal_cdf(X,lambda,1,[Psihat_use(3:end) 1],cutoffs,symmetric)).^2;
        
        theta_U=fminsearch(g_U,X);
        theta_L=fminsearch(g_L,X);
        theta_M=fminsearch(g_M,X);
        
        Theta_U_store(n)=theta_U;
        Theta_L_store(n)=theta_L;
        Theta_M_store(n)=theta_M;
    end
else
    xgrid=-5:.01:5;
    alpha=0.05;
    
    Theta_U_store=zeros(length(xgrid),1);
    Theta_L_store=zeros(length(xgrid),1);
    Theta_M_store=zeros(length(xgrid),1);
    for n=1:length(xgrid)
        X=xgrid(n);
        
        g_U=@(lambda)(alpha/2-Step_function_normal_cdf(X,lambda,1,[Psihat_use(3:end) 1],cutoffs,symmetric)).^2;
        g_L=@(lambda)(1-alpha/2-Step_function_normal_cdf(X,lambda,1,[Psihat_use(3:end) 1],cutoffs,symmetric)).^2;
        g_M=@(lambda) (1/2-Step_function_normal_cdf(X,lambda,1,[Psihat_use(3:end) 1],cutoffs,symmetric)).^2;
        
        theta_U=fminsearch(g_U,X);
        theta_L=fminsearch(g_L,X);
        theta_M=fminsearch(g_M,X);
        
        Theta_U_store(n)=theta_U;
        Theta_L_store(n)=theta_L;
        Theta_M_store(n)=theta_M;
    end
end

%%
if application==7
    fig=figure('Visible','on',...
    'PaperPosition',[0 0 6 6],...
    'PaperSize',[6 6])
else
fig=figure('Visible','on',...
    'PaperPosition',[0 0 4 4],...
    'PaperSize',[4 4])
end

plot(xgrid',[xgrid'-1.96],'Color',GREY,'Linewidth',1.5)
hold on
plot(xgrid',[ xgrid ],'Color',GREY,'Linewidth',1.5)
plot(xgrid',[xgrid'+1.96],'Color',GREY,'Linewidth',1.5)

xmin=min(xgrid);
xmax=max(xgrid);

ymin=min(min(Theta_L_store,xmin-1.96));
ymax=max(max(Theta_U_store,xmax+1.96));

for n=ceil(xmin)+1:1:floor(xmax)-1
    line([n n],[ymin ymax],'LineStyle',':','Color',GREY,'Linewidth',1.5)
end

for n=ceil(ymin):1:floor(ymax)
    line([xmin xmax],[n n],'LineStyle',':','Color',GREY,'Linewidth',1.5)
end

p1=plot(xgrid',[Theta_L_store], 'Color',[.4 .4 .8],'Linewidth',1.5)
p2=plot(xgrid',[ Theta_M_store ], 'Color',[.4 .4 .8],'Linewidth',3)
plot(xgrid',[Theta_U_store], 'Color',[.4 .4 .8],'Linewidth',1.5)

hold off
legend([p1,p2], {'95% Confidence Bounds','Median Unbiased Estimator'},'Location','N','Fontsize',9)
xlabel('X','Fontsize',9)
ylabel('Estimated \theta','Fontsize',9)
axis square tight

%%
print(fig,'-dpdf', ['../FiguresandTables/' name 'Correction_plot.pdf'])
