function [LLH, logL] = VariationVarianceLogLikelihood(lambdabar, tauhat, betap, cutoffs, symmetric, X, sigma,normalizedsign)

%arguments: mean and stdev of distribution pi of mu
%coefficient vector for polynomial logit p
%n vector X of estimates
%vector of stdevs of X

n=length(X);
betap=betap';

%regressors for step function p
T=X./sigma;

Tpowers=zeros(n,length(cutoffs)+1);
if symmetric==1 
        Tpowers(:,1)=abs(T)<cutoffs(1);
    if length(cutoffs)>1
        for m=2:length(cutoffs)
            Tpowers(:,m)=(abs(T)<cutoffs(m)).*(abs(T)>=cutoffs(m-1));
        end
    end
    Tpowers(:,end)=abs(T)>=cutoffs(end);    
else
    Tpowers(:,1)=T<cutoffs(1);
    if length(cutoffs)>1
        for m=2:length(cutoffs)
            Tpowers(:,m)=(T<cutoffs(m)).*(T>=cutoffs(m-1));
        end
    end
    Tpowers(:,end)=T>=cutoffs(end); 
end

%%%%%%%%%%%%%%%%%%%%%%%%
% Calculate objective function LLH

%calculating components of the likelihood
%vector of estimated publication probabilities
phat=Tpowers*betap;

%vector of un-truncated likelihoods
if normalizedsign==1
    fX=0.5*normpdf(X,lambdabar, sqrt(sigma.^2 + tauhat^2))+0.5*normpdf(-X,lambdabar, sqrt(sigma.^2 + tauhat^2));
else
    fX=normpdf(X,lambdabar, sqrt(sigma.^2 + tauhat^2));
end

%normalizing constant
normalizingconst=zeros(n,1);
for i=1:n
    mu_i=lambdabar;
    sigma_tilde_i=sqrt((tauhat)^2 +sigma(i)^2);   
    prob_vec=zeros(length(cutoffs)+1,1);
    if symmetric==1
        for m=1:length(cutoffs)
            prob_vec(m+1)=(normcdf((cutoffs(m)*sigma(i)-mu_i)/sigma_tilde_i)-normcdf((-cutoffs(m)*sigma(i)-mu_i)/sigma_tilde_i));
        end
        prob_vec(end+1,1)=1;
        mean_Z1=prob_vec(2:end,1)-prob_vec(1:end-1,1);
    else
        for m=1:length(cutoffs)
            prob_vec(m+1)=normcdf((cutoffs(m)*sigma(i)-mu_i)/sigma_tilde_i);
        end
        prob_vec(end+1,1)=1;
        mean_Z1=prob_vec(2:end,1)-prob_vec(1:end-1,1);
    end
    normalizingconst(i)=mean_Z1'*betap;
end

%vector of likelihoods
L=phat.*fX./normalizingconst; %cf equation 25 in the draft
logL=log(L);

LLH=-sum(log(L)); %objective function; note the sign flip, since we are doing minimization

end